==> elgg-1.8.19.zip: elgg-1.8.19/mod/thewire/languages/en.php <==
<?php
/**
 * The Wire English language file
 */

$english = array(

	/**
	 * Menu items and titles
	 */
	'thewire' => "The Wire",
	'thewire:everyone' => "All wire posts",
	'thewire:user' => "%s's wire posts",
	'thewire:friends' => "Friends' wire posts",
	'thewire:reply' => "Reply",
	'thewire:replying' => "Replying to %s (@%s) who wrote",
	'thewire:thread' => "Thread",
	'thewire:charleft' => "characters remaining",
	'thewire:tags' => "Wire posts tagged with '%s'",
	'thewire:noposts' => "No wire posts yet",
	'item:object:thewire' => "Wire posts",
	'thewire:update' => 'Update',
	'thewire:by' => 'Wire post by %s',

	'thewire:previous' => "Previous",
	'thewire:hide' => "Hide",
	'thewire:previous:help' => "View previous post",
	'thewire:hide:help' => "Hide previous post",

	/**
	 * The wire river
	 */
	'river:create:object:thewire' => "%s posted to the %s",
	'thewire:wire' => 'wire',

	/**
	 * Wire widget
	 */
	'thewire:widget:desc' => 'Display your latest wire posts',
	'thewire:num' => 'Number of posts to display',
	'thewire:moreposts' => 'More wire posts',

	/**
	 * Status messages
	 */
	'thewire:posted' => "Your message was successfully posted to the wire.",
	'thewire:deleted' => "The wire post was successfully deleted.",
	'thewire:blank' => "Sorry, you need to enter some text before we can post this.",
	'thewire:notfound' => "Sorry, we could not find the specified wire post.",
	'thewire:notdeleted' => "Sorry. We could not delete this wire post.",

	/**
	 * Notifications
	 */
	'thewire:notify:subject' => "New wire post",
	'thewire:notify:reply' => '%s responded to %s on the wire:',
	'thewire:notify:post' => '%s posted on the wire:',

);

add_translation("en", $english);

==> elgg-1.11.0.zip: elgg-1.11.0/mod/thewire/languages/en.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'thewire' => "The Wire",
	'thewire:everyone' => "All wire posts",
	'thewire:user' => "%s's wire posts",
	'thewire:friends' => "Friends' wire posts",
	'thewire:replying' => "Replying to %s (@%s) who wrote",
	'thewire:thread' => "Thread",
	'thewire:charleft' => "characters remaining",
	'thewire:tags' => "Wire posts tagged with '%s'",
	'thewire:noposts' => "No wire posts yet",
	'item:object:thewire' => "Wire posts",
	'thewire:by' => 'Wire post by %s',
	'thewire:previous:help' => "View previous post",
	'thewire:hide:help' => "Hide previous post",

	/**
	 * The wire river
	 */
	'river:create:object:thewire' => "%s posted to %s",
	'thewire:wire' => 'the wire',

	/**
	 * Wire widget
	 */
	'thewire:widget:desc' => 'Display your latest wire posts',
	'thewire:num' => 'Number of posts to display',
	'thewire:moreposts' => 'More wire posts',

	/**
	 * Status messages
	 */
	'thewire:posted' => "Your message was successfully posted to the wire.",
	'thewire:deleted' => "The wire post was successfully deleted.",
	'thewire:blank' => "Sorry, you need to enter some text before we can post this.",
	'thewire:notfound' => "Sorry, we could not find the specified wire post.",
	'thewire:notsaved' => "Sorry. We could not save this wire post.",
	'thewire:notdeleted' => "Sorry. We could not delete this wire post.",

	/**
	 * Notifications
	 */
	'thewire:notify:summary' => 'New wire post: %s',
	'thewire:notify:subject' => "New wire post from %s",
	'thewire:notify:reply' => '%s responded to %s on the wire:',
	'thewire:notify:post' => '%s posted on the wire:',
	'thewire:notify:footer' => "View and reply:\n%s",

	/**
	 * Settings
	 */
	'thewire:settings:limit' => "Maximum number of characters for wire messages:",
	'thewire:settings:limit:none' => "No limit",
);
